```{include} ../README.md
```

# Site content

```{eval-rst}
.. toctree::
   :maxdepth: 3
   :caption: For Users
```

```{eval-rst}
.. autosummary::
    :toctree: api
    :caption: API
    :template: custom-module-template.rst
    :recursive:

    sertit
```

